@@ -7,18 +7,37 @@ class Account {
     $this->password = md5($password);
     $this->config = array();
   }
+
   function authenticate($password) {
     return $this->password == md5($password);
   }
+
+  function changePassword($oldPassword, $newPassword) {
+    if ($this->authenticate($oldPassword)) {
+      $this->setPassword($newPassword);
+      return true;
+    }
+    else {
+      return false;
+    }
+  }
+  function setPassword($password) {
+    $this->password = md5($password);
+  }
+
   function setConfig($key, $value) {
     $this->config[$key] = $value;
   }
+
   function getConfig($key) {
-    return $this->config[$key];
+	$result = isset($this->config[$key]) ? $this->config[$key] : null;
+    return $result;
   }
+
   function configKeys() {
     return keys($this->config);
   }
+
 }
 
 class AccountManager {
