@@ -1,7 +1,8 @@
 <div class="header"><?php MenuFormlet::show() ?></div>
 
-<h2>桼Ͽ</h2>
-<p>桼̾ WikiName ǤʤФʤޤ</p>
+<h1>桼Ͽ</h1>
+<p>桼̾˻ȤʸȾѤαѿѤΤҤ餬ʡʡǤ<br>
+ޤʸʾĹɬפǤ</p>
 
 <?php CreateAccountFormlet::show() ?>
 
